# simunetcore Package

# What is **simunet®**?

Mathematical modeling and simulation as well as model-based optimization are fundamental tools in process engineering. Many questions are answered using these tools. These include, for example, the scale-up of plants and processes, the determination of optimum operating points, control strategies and operations, but in particular also questions of system integration in the development of complex technical systems that consist of a combination of various coupled subsystems. **simunet®** helps to decouple such systems and to solve the underlying mathematical models using waveform relaxation.

Get more info on [simunet.org](https://simunet.org)